@@ -13,25 +13,17 @@
 #'   which will return model summaries.
 #' @inheritParams lme4::glmer
 #'
-#' @importFrom magrittr "%<>%"
-#' @importFrom broom.mixed tidy
 #' @importFrom glue glue
-#' @importFrom purrr map
-#' @importFrom purrr map2_dfr
+#' @importFrom purrr map map2_dfr pmap
 #' @importFrom purrr pmap
-#' @importFrom lme4 glmer
-#' @importFrom lme4 glmerControl
+#' @importFrom lme4 glmer glmerControl
+#' @importFrom sjstats p_value
 #' @importFrom stats as.formula
 #' @importFrom tidyr nest
-#' @importFrom dplyr select
-#' @importFrom dplyr group_by
-#' @importFrom dplyr arrange
-#' @importFrom dplyr mutate
-#' @importFrom dplyr mutate_at
-#' @importFrom dplyr select
-#' @importFrom rlang quo_squash
-#' @importFrom rlang enquo
-#' @importFrom rlang quo
+#' @importFrom rlang !! enquos enquo quo quo_squash
+#' @importFrom dplyr select group_by arrange mutate mutate_at mutate_if
+#' @importFrom dplyr left_join right_join
+#' @importFrom broomExtra tidy glance augment
 #'
 #' @seealso grouped_lmer
 #'
@@ -92,17 +84,13 @@ grouped_glmer <- function(data,
     }
 
   # getting the dataframe ready
-  df <- dplyr::select(
-    .data = data,
-    !!!grouping.vars,
-    dplyr::everything()
-  ) %>%
+  df <- dplyr::select(.data = data, !!!grouping.vars, dplyr::everything()) %>%
     dplyr::group_by(.data = ., !!!grouping.vars) %>%
     tidyr::nest(data = .) %>%
     dplyr::filter(.data = ., !purrr::map_lgl(.x = data, .f = is.null)) %>%
     dplyr::ungroup(x = .)
 
-  # ====================================== custom function ==================================
+  # ============================== custom function ==========================
 
   # custom function to run tidy operation on every element of list column
   fnlisted <-
@@ -117,7 +105,7 @@ grouped_glmer <- function(data,
           list.col %>% # tidying up the output with broom.mixed
           purrr::map_dfr(
             .x = .,
-            .f = ~ broom.mixed::tidy(
+            .f = ~ broomExtra::tidy(
               x = lme4::glmer(
                 formula = stats::as.formula(formula),
                 data = (.),
@@ -138,7 +126,7 @@ grouped_glmer <- function(data,
           list.col %>% # tidying up the output with broom.mixed
           purrr::map_dfr(
             .x = .,
-            .f = ~ broom.mixed::glance(
+            .f = ~ broomExtra::glance(
               x = lme4::glmer(
                 formula = stats::as.formula(formula),
                 data = (.),
