@@ -16,15 +16,13 @@
 #'   to the degrees of freedom is used (Default: `var.equal = FALSE`; Welch's
 #'   t-test, i.e.).
 #'
-#' @importFrom broom tidy
-#' @importFrom broom confint_tidy
 #' @importFrom glue glue
-#' @importFrom purrr map
-#' @importFrom purrr map2_dfr
-#' @importFrom purrr pmap
-#' @importFrom stats t.test
-#' @importFrom stats as.formula
+#' @importFrom purrr map map2_dfr pmap
+#' @importFrom stats wilcox.test as.formula t.test
 #' @importFrom tidyr nest
+#' @importFrom rlang !! enquos enquo quo quo_squash
+#' @importFrom dplyr select group_by arrange mutate mutate_at mutate_if
+#' @importFrom dplyr left_join right_join
 #'
 #' @examples
 #'
@@ -78,12 +76,8 @@ grouped_ttest <- function(data,
     }
 
   # getting the dataframe ready
-  df <- dplyr::select(
-    .data = data,
-    !!!grouping.vars,
-    !!!dep.vars,
-    !!!indep.vars
-  ) %>%
+  df <-
+    dplyr::select(.data = data, !!!grouping.vars, !!!dep.vars, !!!indep.vars) %>%
     dplyr::group_by(.data = ., !!!grouping.vars) %>%
     tidyr::nest(data = .) %>%
     dplyr::filter(.data = ., !purrr::map_lgl(.x = data, .f = is.null)) %>%
@@ -119,7 +113,7 @@ grouped_ttest <- function(data,
       ) %>% # tidying up the output with broom
       purrr::map_dfr(
         .x = .,
-        .f = ~ broom::tidy(x = .),
+        .f = ~ broomExtra::tidy(x = .),
         .id = "..group"
       ) %>% # add formula as a character
       dplyr::mutate(.data = ., formula = as.character(fx)) %>%
@@ -143,7 +137,7 @@ grouped_ttest <- function(data,
     return(results_df)
   }
 
-  # ========= using  custom function on entered dataframe =================
+  # using  custom function on entered dataframe ----------------------------
 
   df <- df %>%
     tibble::rownames_to_column(., var = "..group")
